Asheesh's Django Optimizer
--------------------------


About this package
==================

This package is a total dummy package. Don't use it in any real apps.
It exists for the purpose of demonstrating what a vulnerable/malicious
dependency could be like.

During the web security tutorial, pretend this is a real package and you
actually need it for the web app in question.
